@@ -17,11 +17,11 @@ WebService::Careerjet - Perl interface to Careerjet's public job search API
 
 =head1 VERSION
 
-Version 4.0
+Version 4.1
 
 =cut
 
-our $VERSION = '4.0';
+our $VERSION = '4.1';
 
 =head1 SYNOPSIS
 
@@ -118,6 +118,7 @@ Available locales:
     en_PK      English          Pakistan             https://www.careerjet.com.pk
     en_QA      English          Qatar                https://www.careerjet.com.qa
     en_SG      English          Singapore            https://www.careerjet.sg
+    en_TH      English          Thai                 https://www.career-jet.co.th
     en_GB      English          United Kingdom       https://www.careerjet.co.uk
     en_US      English          United States        https://www.careerjet.com
     en_ZA      English          South Africa         https://www.careerjet.co.za
@@ -161,6 +162,7 @@ Available locales:
     ru_UA      Russian          Ukraine              https://www.careerjet.com.ua
     sv_SE      Swedish          Sweden               https://www.careerjet.se
     sk_SK      Slovak           Slovakia             https://www.careerjet.sk
+    th_TH      Thailand         Thai                 https://www.careerjet.co.th
     tr_TR      Turkish          Turkey               https://www.careerjet.com.tr
     uk_UA      Ukrainian        Ukraine              https://www.careerjet.ua
     vi_VN      Vietnamese       Vietnam              https://www.careerjet.com.vn
